searchData={"items":[{"type":"module","title":"Cldr.Strftime","doc":"","ref":"Cldr.Strftime.html"},{"type":"function","title":"Cldr.Strftime.preferred_formats/3","doc":"","ref":"Cldr.Strftime.html#preferred_formats/3"},{"type":"function","title":"Cldr.Strftime.strftime_options!/2","doc":"Returns a keyword list of options than can be applied to\n`NimbleStrftime.format/3`.\n\nThe hex package [nimble_strftime](https://hex.pm/packages/nimble_strftime)\nprovides a `format/3` function to format dates, times and datetimes.\nIt takes a set of options that can return day, month and am/pm names.\n\n`strftime_options!` returns a keyword list than can be used as these\noptions to return localised names for days, months and am/pm.","ref":"Cldr.Strftime.html#strftime_options!/2"},{"type":"function","title":"Arguments - Cldr.Strftime.strftime_options!/2","doc":"* `locale` is any locale returned by `Cldr.known_locale_names/1`. The\n  default is `Cldr.get_locale/0`\n\n* `options` is a set of keyword options. The default is `[]`","ref":"Cldr.Strftime.html#strftime_options!/2-arguments"},{"type":"function","title":"Options - Cldr.Strftime.strftime_options!/2","doc":"* `:format` determines the format of the date, time or\n  date time. The options are `:short`, `:medium`, `:long`\n  and `:full`. The default is `:medium`.","ref":"Cldr.Strftime.html#strftime_options!/2-options"},{"type":"function","title":"Example - Cldr.Strftime.strftime_options!/2","doc":"=> Cldr.Strftime.strftime_options!\n    [\n      am_pm_names: #Function ,\n      month_names: #Function ,\n      abbreviated_month_names: #Function ,\n      day_of_week_names: #Function ,\n      abbreviated_day_of_week_names: #Function ,\n      preferred_date: \"%b %d, %Y\",\n      preferred_time: \"%H:%M:%S %p\",\n      preferred_datetime: \"%b %d, %Y, %H:%M:%S %p\"\n    ]","ref":"Cldr.Strftime.html#strftime_options!/2-example"},{"type":"function","title":"Typical usage from Elixir 1.11 - Cldr.Strftime.strftime_options!/2","doc":"iex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%x\", Cldr.Strftime.strftime_options!\n    \"Aug 26, 2019\"\n\n    iex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%X\", Cldr.Strftime.strftime_options!\n    \"13:52:06 PM\"\n\n    iex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%c\", Cldr.Strftime.strftime_options!\n    \"Aug 26, 2019, 13:52:06 PM\"","ref":"Cldr.Strftime.html#strftime_options!/2-typical-usage-from-elixir-1-11"},{"type":"extras","title":"Calendar.strftime options generator for CLDR","doc":"# Calendar.strftime options generator for CLDR\n\n[Calendar.strftime/3](https://hexdocs.pm/elixir/Calendar.html#strftime/3) has been available since Elixir 1.11 to provide date/datetime formatting using the principles that date back to at least [1978](https://en.wikipedia.org/wiki/The_C_Programming_Language).\n\nThe functions in this library are intended to serve options to `Calendar.strftime/3` to support localisation of dates/datetimes leveraging the content in [CLDR](https://cldr.unicode.org). Therefore a developer can take advantage of the built-in localised formats from `CLDR` with well-known `strftime` formatting strings.\n\n#","ref":"readme.html"},{"type":"extras","title":"Installation - Calendar.strftime options generator for CLDR","doc":"The package can be installed by adding `cldr_strftime` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_cldr_strftime, \"~> 0.2.0\"}\n  ]\nend\n```\n\n#","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Calendar.strftime options generator for CLDR","doc":"Update your `ex_cldr` backend module to include the provider module `Cldr.Strftime`. For example:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"fr\", \"af\", \"ja\", \"de\", \"pl\", \"th\"],\n    providers: [Cldr.Number, Cldr.Calendar, Cldr.DateTime, Cldr.Strftime]\nend\n```\n\nDocumentation is available at [https://hexdocs.pm/cldr_strftime](https://hexdocs.pm/cldr_strftime).\n\n#","ref":"readme.html#configuration"},{"type":"extras","title":"Keyword Options returned - Calendar.strftime options generator for CLDR","doc":"In accordance with the options defined for `Calendar.strftime/3`, `Cldr.Strftime.strftime_options!/2` returns the following keyword list:\n\n* `:preferred_datetime` - a string for the preferred format to show datetimes,\n\n* `:preferred_date` - a string for the preferred format to show dates.\n\n* `:preferred_time` - a string for the preferred format to show times.\n\n* `:am_pm_names` - a function that receives either :am or :pm and returns the name of the period of the day\n\n* `:month_names` - a function that receives a number and returns the name of the corresponding month.\n\n* `:abbreviated_month_names` - a function that receives a number and returns the abbreviated name of the corresponding month.\n\n* `:day_of_week_names` - a function that receives a number and returns the name of the corresponding day of week.\n\n* `:abbreviated_day_of_week_names` - a function that receives a number and returns the abbreviated name of the corresponding day of week\n\n#","ref":"readme.html#keyword-options-returned"},{"type":"extras","title":"CLDR format translation - Calendar.strftime options generator for CLDR","doc":"[CLDR](https://cldr.unicode.org) [formats dates, times and date times](https://unicode.org/reports/tr35/tr35-dates.html#Contents) using a [different formatting system](https://unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table) to that of `Calendar.strftime/3`.  The CLDR formats are translated at compile time according to the following table. Since them formats are translated at compile time, performance is comparable to using native `Calendar.strftime/3`formats natively.\n\nStrftime | CLDR     | Description                                                   | Examples (in ISO)\n-------- | ---------| ------------------------------------------------------------- | ------------------\na        | E,EE,EEE | Abbreviated name of day                                       | Mon\nA        | EEEE     | Full name of day                                              | Monday\nb        | MMM      | Abbreviated month name                                        | Jan\nB        | MMMM     | Full month name                                               | January\nd        | d        | Day of the month                                              | 01, 12\nH        | h        | Hour using a 24-hour clock                                    | 00, 23\nI        | H        | Hour using a 12-hour clock                                    | 01, 12\nj        | DDD      | Day of the year                                               | 001, 366\nm        | MM       | Month                                                         | 01, 12\nM        | mm       | Minute                                                        | 00, 59\np        | a,aa,aaa | \"AM\" or \"PM\" (noon is \"PM\", midnight as \"AM\")                 | AM, PM\nq        | Q        | Quarter                                                       | 1, 2, 3, 4\nS        | ss       | Second                                                        | 00, 59, 60\nu        | s        | Day of the week                                               | 1 (Monday), 7 (Sunday)\ny        | YY       | Year as 2-digits                                              | 01, 01, 86, 18\nY        | YYYY     | Year                                                          | -0001, 0001, 1986\nz        | ZZZZ     | +hhmm/-hhmm time zone offset from UTC (empty string if naive) | +0300, -0530\nZ        | V, VV    | Time zone abbreviation (empty string if naive)                | CET, BRST\n\n[Calendar.strftime/3](https://hexdocs.pm/elixir/Calendar.html#strftime/3) allows for a set of options to guide formatting\n\n#","ref":"readme.html#cldr-format-translation"},{"type":"extras","title":"Example usage - Calendar.strftime options generator for CLDR","doc":"These examples use the `%c`, `%x` and `%X` format flags which means \"use the preferred_* option if provided\".\n\n```elixir\niex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%x\", Cldr.Strftime.strftime_options!()\n\"Aug 26, 2019\"\n\niex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%X\", Cldr.Strftime.strftime_options!()\n\"13:52:06 PM\"\n\niex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%c\", Cldr.Strftime.strftime_options!()\n\"Aug 26, 2019, 13:52:06 PM\"\n\niex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%c\", Cldr.Strftime.strftime_options!(\"ja\")\n\"2019/08/26 13:52:06\"\n\niex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%c\", Cldr.Strftime.strftime_options!(\"ja\", format: :long)\n\"2019年08月26日 13:52:06 +0000\"\n\niex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%c\", Cldr.Strftime.strftime_options!(\"pl\")\n\"26 sie 2019, 13:52:06\"\n\niex> Calendar.strftime ~U[2019-08-26 13:52:06.0Z], \"%c\", Cldr.Strftime.strftime_options!(\"pl\", format: :long)\n\"26 sierpnia 2019 13:52:06 +0000\"\n```","ref":"readme.html#example-usage"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Cldr_Strftime v1.0.1 - Changelog","doc":"This is the changelog for Cldr_Strftime v1.0.1 released on September 30th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_strftime/tags)\n\n#","ref":"changelog.html#cldr_strftime-v1-0-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes code ambiguity by wrapping parens. Thanks to @rubas for the report. Closes #2.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr_Strftime v1.0.0 - Changelog","doc":"This is the changelog for Cldr_Strftime v1.0.0 released on December 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_strftime/tags)\n\n#","ref":"changelog.html#cldr_strftime-v1-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Bump to version 1.0.0 since the API has been stable for over a year\n\n* Update requirement for CLDR40-based releases of `ex_cldr` to remove deprecation warnings.  Thanks to @zenbaku for the PR.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Strftime v0.2.0 - Changelog","doc":"This is the changelog for Cldr_Strftime v0.2.0 released on March 18th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_strftime/tags)\n\n#","ref":"changelog.html#cldr_strftime-v0-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update documentation and benchmarks","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr_Strftime v0.1.0 - Changelog","doc":"This is the changelog for Cldr_Strftime v0.1.0 released on November 29th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_strftime/tags)\n\n#","ref":"changelog.html#cldr_strftime-v0-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Initial release","ref":"changelog.html#enhancements"},{"type":"extras","title":"LICENSE","doc":"","ref":"license.html"},{"type":"extras","title":"License - LICENSE","doc":"Copyright 2020 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html#license"}],"content_type":"text/markdown"}